@@ -1,24 +1,21 @@
+package GitHub::MergeVelocity;
+$GitHub::MergeVelocity::VERSION = '0.000005';
 use strict;
 use warnings;
 
-package GitHub::MergeVelocity;
-$GitHub::MergeVelocity::VERSION = '0.000004';
-use CHI;
-use CLDR::Number::Format::Percent;
-use File::HomeDir;
-use GitHub::MergeVelocity::Repository;
+use CLDR::Number::Format::Percent     ();
+use File::HomeDir                     ();
+use GitHub::MergeVelocity::Repository ();
+use Module::Runtime qw( require_module use_module );
 use Moo;
 use MooX::HandlesVia;
 use MooX::Options;
 use MooX::StrictConstructor;
-use Path::Tiny;
-use Pithub::PullRequests;
+use Path::Tiny qw( path );
+use Pithub::PullRequests ();
 use Text::SimpleTable::AutoWidth;
 use Types::Standard qw( ArrayRef Bool HashRef InstanceOf Int Str );
-use WWW::Mechanize::Cached;
-use WWW::Mechanize::GZip;
-
-with 'MooseX::Getopt::Dashes';
+use WWW::Mechanize::GZip ();
 
 option debug_useragent => (
     is            => 'ro',
@@ -114,10 +111,11 @@ sub _build_mech {
         my $dir = path( File::HomeDir->my_home );
         $dir->child('.github-mergevelocity-cache')->mkpath;
 
-        $mech = WWW::Mechanize::Cached->new(
+        require_module('CHI');
+        $mech = use_module( 'WWW::Mechanize::Cached', 1.45 )->new(
             cache => CHI->new(
                 driver   => 'File',
-                root_dir => $dir,
+                root_dir => $dir->stringify,
             )
         );
     }
@@ -125,7 +123,7 @@ sub _build_mech {
         $mech = WWW::Mechanize::GZip->new;
     }
     if ( $self->debug_useragent ) {
-        require LWP::ConsoleLogger::Easy;
+        use_module( 'LWP::ConsoleLogger::Easy', 0.000013 );
         LWP::ConsoleLogger::Easy::debug_ua( $mech, $self->debug_useragent );
     }
     return $mech;
@@ -218,7 +216,7 @@ GitHub::MergeVelocity - Determine how quickly your pull request might get merged
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 SYNOPSIS
 
