@@ -1,8 +1,8 @@
+package GitHub::MergeVelocity::Repository;
+$GitHub::MergeVelocity::Repository::VERSION = '0.000005';
 use strict;
 use warnings;
 
-package GitHub::MergeVelocity::Repository;
-$GitHub::MergeVelocity::Repository::VERSION = '0.000004';
 use GitHub::MergeVelocity::Repository::PullRequest;
 use GitHub::MergeVelocity::Repository::Statistics;
 use Moo;
@@ -58,9 +58,10 @@ sub _build_report {
     my $self = shift;
 
     my $pulls = $self->_get_pull_requests;
+
     my $total = $pulls ? scalar @{$pulls} : 0;
 
-    my %summary;
+    my %summary = ( total_velocity => 0 );
 
     foreach my $pr ( @{$pulls} ) {
         $summary{ $pr->state }++;
@@ -71,6 +72,7 @@ sub _build_report {
     return GitHub::MergeVelocity::Repository::Statistics->new(%summary);
 }
 
+## no critic (ValuesAndExpressions::ProhibitAccessOfPrivateData)
 sub _get_pull_requests {
     my $self = shift;
 
@@ -100,6 +102,7 @@ sub _get_pull_requests {
     }
     return \@pulls;
 }
+## use critic
 
 sub _parse_github_url {
     my $self = shift;
@@ -127,7 +130,7 @@ GitHub::MergeVelocity::Repository - Encapsulate pull request data for a reposito
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 AUTHOR
 
