@@ -1,8 +1,8 @@
+package GitHub::MergeVelocity::Repository::PullRequest;
+$GitHub::MergeVelocity::Repository::PullRequest::VERSION = '0.000005';
 use strict;
 use warnings;
 
-package GitHub::MergeVelocity::Repository::PullRequest;
-$GitHub::MergeVelocity::Repository::PullRequest::VERSION = '0.000004';
 use DateTime;
 use GitHub::MergeVelocity::Types qw( Datetime );
 use Math::Round qw( round );
@@ -122,7 +122,7 @@ sub _build_velocity {
     elsif ( $self->age > 45 ) {
         $score = 45 - $self->age;
     }
-    return $self->is_merged ? $score : round( $score / 2 );
+    return $score;
 }
 
 1;
@@ -137,7 +137,7 @@ GitHub::MergeVelocity::Repository::PullRequest - Encapsulate select data about G
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 AUTHOR
 
